==> daed-0.2.0.tar.xz: daed-0.2.0/README.md <==
<h1 align="center">daed</h1>
<p align="center">
  <img width="100" src="public/logo.svg" />
</p>
<p align="center">
  <em>A modern web dashboard for dae</em>
</p>

<p align="center">
  <img src="https://github.com/daeuniverse/daed/actions/workflows/build.yml/badge.svg" alt="build-status" />
  <img src="https://custom-icon-badges.herokuapp.com/github/license/daeuniverse/daed?logo=law&color=orange" alt="license" />
  <img src="https://hits.seeyoufarm.com/api/count/incr/badge.svg?url=https%3A%2F%2Fgithub.com%2Fdaeuniverse%2Fdaed&count_bg=%235C3DC8&title_bg=%23555555&icon=&icon_color=%23E7E7E7&title=hits&edge_flat=false" alt="hits" />
  <img src="https://custom-icon-badges.herokuapp.com/github/v/release/daeuniverse/daed?logo=rocket" alt="version">
  <img src="https://custom-icon-badges.herokuapp.com/github/issues-pr-closed/daeuniverse/daed?color=purple&logo=git-pull-request&logoColor=white" alt="pr/issue" />
  <img src="https://custom-icon-badges.herokuapp.com/github/last-commit/daeuniverse/daed?logo=history&logoColor=white" alt="lastcommit" />
</p>

## Preview

![preview](docs/preview.png)

## Features

- [x] Easy to use, with keyboard navigation / shortcuts builtin
- [x] Beautiful and intuitive UI
- [x] Light / Dark mode
- [x] Mobile friendly

## Getting Started

Please refer to [Quick Start Guide](./docs/getting-started.md) to start using `daed` right away!

## Contrubuting

Feel free to open issues or submit your PR, any feedbacks or help are greatly appreciated.

Special thanks go to all [contributors](https://github.com/daeuniverse/daed/graphs/contributors). If you would like to contribute, please see the [instructions](./CONTRIBUTING.md). Also, it is recommended following the [commit-msg-guide](./docs/commit-msg-guide.md).

## License

Made with passion 🔥 by [@daeuniverse](https://github.com/daeuniverse)

The project is dual licensed under the [GNU Affero General Public License v3.0 (dae-wing)](https://github.com/daeuniverse/dae-wing/blob/main/LICENSE) and the [MIT License (daed)](https://github.com/daeuniverse/daed/blob/main/LICENSE).

### Dependencies used in this project

- [Graphql](https://graphql.org)
- [React](https://reactjs.org)
- [Mantine](https://mantine.dev)
- [dnd kit](https://dndkit.com)

==> daed-0.4.0rc1.tar.xz: daed-0.4.0rc1/README.md <==
<h1 align="center">daed</h1>
<p align="center">
  <img width="100" src="public/logo.webp" />
</p>
<p align="center">
  <em>A modern web dashboard for dae</em>
</p>

<p align="center">
  <img src="https://github.com/daeuniverse/daed/actions/workflows/build.yml/badge.svg" alt="build-status" />
  <img src="https://custom-icon-badges.herokuapp.com/github/license/daeuniverse/daed?logo=law&color=orange" alt="license" />
  <img src="https://hits.seeyoufarm.com/api/count/incr/badge.svg?url=https%3A%2F%2Fgithub.com%2Fdaeuniverse%2Fdaed&count_bg=%235C3DC8&title_bg=%23555555&icon=&icon_color=%23E7E7E7&title=hits&edge_flat=false" alt="hits" />
  <img src="https://custom-icon-badges.herokuapp.com/github/v/release/daeuniverse/daed?logo=rocket" alt="version">
  <img src="https://custom-icon-badges.herokuapp.com/github/issues-pr-closed/daeuniverse/daed?color=purple&logo=git-pull-request&logoColor=white" alt="pr/issue" />
  <img src="https://custom-icon-badges.herokuapp.com/github/last-commit/daeuniverse/daed?logo=history&logoColor=white" alt="lastcommit" />
</p>

## Preview

![preview](docs/preview.webp)

## Features

- [x] Easy to use, with keyboard navigation / shortcuts builtin
- [x] Beautiful and intuitive UI
- [x] Light / Dark mode
- [x] Mobile friendly

## Getting Started

Please refer to [Quick Start Guide](./docs/getting-started.md) to start using `daed` right away!

## Contrubuting

Feel free to open issues or submit your PR, any feedbacks or help are greatly appreciated.

Special thanks go to all [contributors](https://github.com/daeuniverse/daed/graphs/contributors). If you would like to contribute, please see the [instructions](./CONTRIBUTING.md). Also, it is recommended following the [commit-msg-guide](./docs/commit-msg-guide.md).

## License

Made with passion 🔥 by [@daeuniverse](https://github.com/daeuniverse)

The project is dual licensed under the [GNU Affero General Public License v3.0 (dae-wing)](https://github.com/daeuniverse/dae-wing/blob/main/LICENSE) and the [MIT License (daed)](https://github.com/daeuniverse/daed/blob/main/LICENSE).

### Dependencies used in this project

- [Graphql](https://graphql.org)
- [React](https://reactjs.org)
- [Mantine](https://mantine.dev)
- [dnd kit](https://dndkit.com)
